==> jbpm-distribution-6.1.0.CR1-src.zip: jbpm-human-task/jbpm-human-task-audit/src/main/java/org/jbpm/services/task/audit/commands/GetAllHistoryAuditTasksByUserCommand.java <==
package org.jbpm.services.task.audit.commands;

import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;
import org.jbpm.services.task.audit.impl.model.api.AuditTask;
import org.jbpm.services.task.commands.TaskCommand;
import org.jbpm.services.task.query.QueryFilterImpl;
import org.jbpm.services.task.utils.ClassUtil;
import org.kie.internal.command.Context;
import org.kie.internal.task.api.QueryFilter;
import org.kie.internal.task.api.TaskContext;
import org.kie.internal.task.api.TaskPersistenceContext;

@XmlRootElement(name="get-all-audit-tasks-by-user-command")
@XmlAccessorType(XmlAccessType.NONE)
public class GetAllHistoryAuditTasksByUserCommand extends TaskCommand<List<AuditTask>> {
        private QueryFilter filter;
        private String owner;
	public GetAllHistoryAuditTasksByUserCommand() {
            this.filter =  new QueryFilterImpl(0,0);
	}

        public GetAllHistoryAuditTasksByUserCommand(String owner, QueryFilter filter) {
            this.owner = owner;
            this.filter = filter;
        }
        
	@Override
	public List<AuditTask> execute(Context context) {
		TaskPersistenceContext persistenceContext = ((TaskContext) context).getPersistenceContext();
		return persistenceContext.queryWithParametersInTransaction("getAllAuditTasksByUser", 
                                persistenceContext.addParametersToMap("owner", owner, "firstResult", filter.getOffset(), 
                                        "maxResults", filter.getCount()),
				ClassUtil.<List<AuditTask>>castClass(List.class));
	}

}

==> jbpm-distribution-6.3.0.CR1-src.zip: jbpm-human-task/jbpm-human-task-audit/src/main/java/org/jbpm/services/task/audit/commands/GetAllHistoryAuditTasksByUserCommand.java <==
/*
 * Copyright 2015 JBoss Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
*/

package org.jbpm.services.task.audit.commands;

import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;

import org.kie.internal.task.api.AuditTask;
import org.jbpm.services.task.commands.TaskCommand;
import org.jbpm.services.task.utils.ClassUtil;
import org.kie.internal.command.Context;
import org.kie.internal.query.QueryFilter;
import org.kie.internal.task.api.TaskContext;
import org.kie.internal.task.api.TaskPersistenceContext;

@XmlRootElement(name="get-all-audit-tasks-by-user-command")
@XmlAccessorType(XmlAccessType.NONE)
public class GetAllHistoryAuditTasksByUserCommand extends TaskCommand<List<AuditTask>> {
        private QueryFilter filter;
        private String owner;
	public GetAllHistoryAuditTasksByUserCommand() {
            this.filter =  new QueryFilter(0,0);
	}

        public GetAllHistoryAuditTasksByUserCommand(String owner, QueryFilter filter) {
            this.owner = owner;
            this.filter = filter;
        }
        
	@Override
	public List<AuditTask> execute(Context context) {
		TaskPersistenceContext persistenceContext = ((TaskContext) context).getPersistenceContext();
		return persistenceContext.queryWithParametersInTransaction("getAllAuditTasksByUser", 
                                persistenceContext.addParametersToMap("owner", owner, "firstResult", filter.getOffset(), 
                                        "maxResults", filter.getCount()),
				ClassUtil.<List<AuditTask>>castClass(List.class));
	}

}
